# -*- coding: utf-8 -*-
import logging
import os
from typing import NamedTuple

import cv2
import numpy as np

logging.basicConfig(
    level=logging.INFO, format="%(asctime)s %(levelname)s/%(name)s: %(message)s"
)
logger = logging.getLogger(os.path.basename(__file__))

BoundingBox = NamedTuple(
    "BoundingBox", [("x", int), ("y", int), ("width", int), ("height", int)]
)


class TranscriptionData:
    def __init__(self, element_id, polygon, text, rotation_class=None):
        self.element_id = element_id
        self.polygon = np.asarray(polygon).clip(0)
        self.text = text
        self.rotation_class = rotation_class

        self.rect = BoundingBox._make(cv2.boundingRect(self.polygon))

    @property
    def is_vertical(self) -> bool:
        """
        Used to filter out vertical lines. Will be ignored when rotation class is given.
        """
        if self.rotation_class is None:
            return self.rect.height > self.rect.width
        return False

    def __repr__(self):
        return str(vars(self))


def write_file(file_name, content):
    with open(file_name, "w") as f:
        f.write(content)
